#
# spec file for package octave
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Use native graphics or gnuplot
%define with_native_graphics 1
# Build GUI
%define with_gui 1
# JIT compilation
%define with_jit 0
# JAVA support
%define with_java 1
# Image processing library
# Default variant - GraphicsMagick
%define with_imagemagick 0
# Sound IO
%define with_sound 1

# SLE11
%if 0%{?suse_version} == 1110
%define with_gui 0
%define with_jit 0
%define with_imagemagick 1
%endif

# SLE12
%if 0%{?suse_version} == 1315 && 0%{?is_opensuse} == 0
%define with_gui 0
%define with_jit 0
%define with_imagemagick 1
%endif

Name:           octave
Version:        4.0.3
Release:        2.22
# Required for RC builds, in this case version contains ~rc, src_ver -rc
%define src_ver %{version}
Summary:        A High Level Programming Language
License:        GPL-3.0+
Group:          Productivity/Scientific/Math
%define apiver  v50+
Url:            http://www.octave.org/
Source:         ftp://ftp.gnu.org/gnu/octave/%{name}-%{src_ver}.tar.xz
Source2:        octave.pc.in
Source3:        octave.macros
Patch1:         octave-gcc6.patch
BuildRequires:  arpack-ng-devel
BuildRequires:  bison
BuildRequires:  blas-devel
BuildRequires:  dejagnu
BuildRequires:  fftw3-threads-devel
BuildRequires:  flex
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  gl2ps-devel
BuildRequires:  glpk-devel
BuildRequires:  gmp-devel
BuildRequires:  gnuplot
BuildRequires:  gperf
BuildRequires:  hdf5-devel
BuildRequires:  lapack-devel
%if 0%{?with_imagemagick}
BuildRequires:  libMagick++-devel
%else
BuildRequires:  libGraphicsMagick++-devel
%endif
BuildRequires:  libcurl-devel
BuildRequires:  liblcms-devel
BuildRequires:  pcre-devel
BuildRequires:  pkg-config
BuildRequires:  qhull-devel
BuildRequires:  qrupdate-devel
BuildRequires:  readline-devel
BuildRequires:  suitesparse-devel
BuildRequires:  termcap
BuildRequires:  texinfo
%if 0%{?suse_version} > 1220
BuildRequires:  texlive-dvips
%endif
BuildRequires:  texlive-latex
BuildRequires:  xz
BuildRequires:  zlib-devel
# GUI build requires
%if 0%{?with_gui}
BuildRequires:  desktop-file-utils
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt4-devel
BuildRequires:  qscintilla-devel
BuildRequires:  update-desktop-files
Obsoletes:      octave-gui < 4.0
%endif
# Sound IO build requires
%if 0%{?with_sound}
BuildRequires:  alsa-devel
BuildRequires:  libsndfile-devel
BuildRequires:  portaudio-devel
%endif
# JAVA functions build requires
%if 0%{?with_java}
BuildRequires:  java-devel
%endif
# JIT build requires
%if 0%{?with_jit}
BuildRequires:  llvm-devel
%endif
# Native graphics build requires
%if 0%{?with_native_graphics}
%if 0%{?suse_version} > 1220
BuildRequires:  glu-devel
%endif
BuildRequires:  Mesa-devel
BuildRequires:  fltk-devel
BuildRequires:  fontconfig-devel
BuildRequires:  xorg-x11-devel
BuildRequires:  xorg-x11-libSM-devel
BuildRequires:  xorg-x11-libX11-devel
BuildRequires:  xorg-x11-libXext-devel
%else
Requires:       gnuplot
%endif
# Tests build requires
BuildRequires:  unzip
BuildRequires:  zip
Requires:       octave-cli = %{version}
Requires(post): update-alternatives
Requires(preun): update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Octave is a high level programming language. It is designed for the
solution of numeric problems. There is a command line interface
supplied.
%if 0%{?with_gui}
This package contains graphical user interface.
%endif

%package        cli
Summary:        Command-line user interface for Octave
Group:          Productivity/Scientific/Math
Requires:       makeinfo
Requires(post): update-alternatives
Requires(preun): update-alternatives
%if 0%{?with_native_graphics}
Recommends:     epstool
Recommends:     pstoedit
Recommends:     transfig
%endif
Recommends:     octave-devel = %{version}
Recommends:     octave-doc = %{version}

%description    cli
Octave is a high level programming language. It is designed for the
solution of numeric problems.

This package contains command-line user interface.

%package        devel
Summary:        Development files for Octave
Group:          Productivity/Scientific/Math
Requires:       %{name}-cli = %{version}
Recommends:     blas-devel
Recommends:     fftw3-devel
Recommends:     fftw3-threads-devel
Recommends:     gcc
Recommends:     gcc-fortran
Recommends:     hdf5-devel
Recommends:     make

%description    devel
Octave is a high level programming language. It is designed for the
solution of numeric problems.

This package contains all necessary include files and libraries needed
to develop applications using Octave.

%package        doc
Summary:        Documentation for Octave
Group:          Documentation/Other
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif

%description    doc
Octave is a high level programming language. It is designed for the
solution of numeric problems.

This package contains documentation for Octave.

%if 0%{?suse_version} > 1320
%if %( echo `rpm -q --queryformat %%{version} gcc` ) > 5
%define with_gcc6 1
%endif
%endif

%prep
%setup -q -n %{name}-%{src_ver}
%if 0%{?with_gcc6}
%patch1 -p1
find -name \*.cc -o -name \*.h -o -name \*.yy | xargs sed -i -e 's/#include <c\(math\|stdlib\)>/#include <\1.h>/'
find -name \*.h -o -name \*.cc | xargs sed -i -e 's/<config.h>/"config.h"/' -e 's/<base-list.h>/"base-list.h"/'
%endif

%build
export CPPFLAGS="-DH5_USE_16_API"
%configure \
  --libexecdir=%{_libdir} \
  %if %{?with_gui} == 0
  --disable-gui \
  %endif
  %if %{?with_jit} == 1
  --enable-jit \
  %endif
  %if %{?with_java} == 0
  --disable-java \
  %endif
  %if 0%{?suse_version} <= 1310
  --with-umfpack="-lumfpack -lcholmod -lcolamd -lsuitesparseconfig -lrt -llapack" \
  --with-cholmod="-lcholmod -lsuitesparseconfig -lrt" \
  %endif
  --enable-openmp

make %{?_smp_mflags}

# .pc file
cp %{SOURCE2} octave.pc
sed -i 's:@VERSION@:%{src_ver}:' octave.pc
sed -i 's:@LIB@:%{_lib}:' octave.pc

%install
%make_install
# see bnc#557340
mkdir -p %{buildroot}/%{_sysconfdir}/ld.so.conf.d
echo %{_libdir}/%{name}/%{src_ver} > %{buildroot}/%{_sysconfdir}/ld.so.conf.d/%{name}.conf
rm %{buildroot}/%{_libdir}/%{name}/%{src_ver}/*.la
# local rc file into /etc
mkdir %{buildroot}/%{_sysconfdir}/%{name}
mv %{buildroot}/%{_datadir}/%{name}/site/m/startup/octaverc %{buildroot}/%{_sysconfdir}/%{name}
ln -s %{_sysconfdir}/%{name}/octaverc %{buildroot}/%{_datadir}/%{name}/site/m/startup/octaverc
#
mkdir -p %{buildroot}/%{_libdir}/%{name}/packages
mkdir -p %{buildroot}/%{_datadir}/%{name}/packages
# .pc file
mkdir -p %{buildroot}/%{_libdir}/pkgconfig
cp octave.pc %{buildroot}/%{_libdir}/pkgconfig
# big icons size
%if 0%{?suse_version} <= 1320
rm -rf %{buildroot}/%{_datadir}/icons/hicolor/512x512/
%endif
# gui related fixes
%if %{?with_gui}
mv %{buildroot}/%{_datadir}/applications/*octave.desktop %{buildroot}/%{_datadir}/applications/octave.desktop
%suse_update_desktop_file -r octave "Science;Math"
# appdata
mv %{buildroot}%{_datadir}/appdata/*octave.appdata.xml %{buildroot}%{_datadir}/appdata/octave.appdata.xml
sed -i 's/www.octave.org-octave.desktop/octave.desktop/' %{buildroot}%{_datadir}/appdata/octave.appdata.xml
sed -i 's/screenshot.png/screenshot-2016.png/' %{buildroot}%{_datadir}/appdata/octave.appdata.xml
%else
rm -rf %{buildroot}/%{_datadir}/icons/hicolor/
rm -rf %{buildroot}/%{_datadir}/appdata/
%endif
# rpm macros
install -Dm 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/rpm/macros.octave
# dummy target for update-alternatives
install -d %{buildroot}/%{_sysconfdir}/alternatives
ln -s %{name} %{buildroot}/%{_sysconfdir}/alternatives/%{name}
# move gui binaries
mv %{buildroot}/%{_bindir}/%{name} %{buildroot}/%{_bindir}/%{name}-gui
mv %{buildroot}/%{_bindir}/%{name}-%{src_ver} %{buildroot}/%{_bindir}/%{name}-gui-%{src_ver}

ln -s %{name}-%{src_ver} %{buildroot}/%{_bindir}/%{name}
ln -s %{name}-cli-%{src_ver} %{buildroot}/%{_bindir}/%{name}-%{src_ver}

%check
make check

%post
%{_sbindir}/update-alternatives --install %{_bindir}/%{name}-%{src_ver} %{name} %{_bindir}/%{name}-gui-%{src_ver} 50
/sbin/ldconfig

%posttrans
if [ "$1" = 0 ] ; then
  if ! [ -f %{_bindir}/%{name}-%{src_ver} ] ; then
      %{_sbindir}/update-alternatives --auto %{name}
  fi
fi

%preun
if [ "$1" = 0 ] ; then
   %{_sbindir}/update-alternatives --remove %{name} %{_bindir}/%{name}-gui-%{src_ver}
fi

%postun
/sbin/ldconfig

%post cli
%{_sbindir}/update-alternatives --install %{_bindir}/%{name}-%{src_ver} %{name} %{_bindir}/%{name}-cli-%{src_ver} 20
/sbin/ldconfig
%install_info --info-dir=%{_infodir} %{_infodir}/octave.info.gz

%posttrans cli
if [ "$1" = 0 ] ; then
  if ! [ -f %{_bindir}/%{name}-%{src_ver} ] ; then
      %{_sbindir}/update-alternatives --auto %{name}
  fi
fi

%preun cli
if [ "$1" = 0 ] ; then
   %{_sbindir}/update-alternatives --remove %{name} %{_bindir}/%{name}-cli-%{src_ver}
fi

%postun cli
/sbin/ldconfig
%install_info_delete --info-dir=%{_infodir} %{_infodir}/octave.info.gz

%files
%defattr(-,root,root,-)
%doc AUTHORS BUGS COPYING NEWS
%doc README ChangeLog
%ghost %{_sysconfdir}/alternatives/%{name}
%ghost %{_bindir}/%{name}-%{src_ver}
%{_bindir}/%{name}-gui
%{_bindir}/%{name}-gui-%{src_ver}
%if 0%{?with_gui}
%{_libdir}/%{name}/%{src_ver}/exec/*-*-linux-gnu*/octave-gui
%{_libdir}/%{name}/%{src_ver}/liboctgui.so.*
%{_datadir}/%{name}/%{src_ver}/locale/
%{_datadir}/appdata/*.xml
%{_datadir}/applications/*.desktop
%if 0%{?suse_version} <= 1315
%dir %{_datadir}/appdata
%endif
%{_datadir}/icons/hicolor/*/apps/octave.*
%endif

%files cli
%defattr(-,root,root)
%{_bindir}/%{name}
%ghost %{_bindir}/%{name}-%{src_ver}
%ghost %{_sysconfdir}/alternatives/%{name}
%{_bindir}/octave-cli
%{_bindir}/octave-cli-%{src_ver}
%{_mandir}/man1/octave.1.gz
%{_mandir}/man1/octave-cli.1.gz
%{_bindir}/mkoctfile
%{_bindir}/mkoctfile-%{src_ver}
%{_mandir}/man1/mkoctfile.1.gz
%{_bindir}/octave-config
%{_bindir}/octave-config-%{src_ver}
%{_mandir}/man1/octave-config.1.gz
%{_infodir}/*.gz
%config %{_sysconfdir}/ld.so.conf.d/%{name}.conf
%config(noreplace) %{_sysconfdir}/%{name}/octaverc
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/%{src_ver}
%dir %{_libdir}/%{name}/packages
%dir %{_datadir}/%{name}/packages
%dir %{_sysconfdir}/%{name}
%{_libdir}/%{name}/%{src_ver}/oct
%{_libdir}/%{name}/%{src_ver}/liboctave.so.*
%{_libdir}/%{name}/%{src_ver}/liboctinterp.so.*
%if 0%{?with_gui}
%dir %{_libdir}/%{name}/%{src_ver}/exec/
%dir %{_libdir}/%{name}/%{src_ver}/exec/*-*-linux-gnu*/
%exclude %{_datadir}/%{name}/%{src_ver}/locale/
%endif
%{_datadir}/octave/
%{_libdir}/%{name}/site
%{_libdir}/pkgconfig/octave.pc

%files devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/%{name}/%{src_ver}/lib*.so
%{_libdir}/%{name}/api-%{apiver}
%config %{_sysconfdir}/rpm/macros.octave

%files doc
%defattr(-,root,root)
%doc doc/interpreter/octave.pdf
%doc doc/liboctave/liboctave.pdf
%doc doc/refcard/refcard-a4.pdf
%doc doc/refcard/refcard-legal.pdf

%changelog
* Fri Jul 29 2016 dmitry_r@opensuse.org
- Use original appdata file
- Fix SLE12 build
* Thu Jul 28 2016 badshah400@gmail.com
- Update to version 4.0.3:
  * Bug fix release, see
    http://www.gnu.org/software/octave/fixes-4-0-3.html for a full
    list of fixes.
- Add appdata file as source, and install it to
  /usr/share/appdata; this makes octave appear on appstores like
  gnome-software and KDE Discover.
- Rebase octave-gcc6.patch for current version.
* Sat Jun 18 2016 dmitry_r@opensuse.org
- Fix build with GCC6 [boo#985363]
  * octave-gcc6.patch
* Tue Jun  7 2016 dmitry_r@opensuse.org
- Update to version 4.0.2
  * Bugfix release
- Fix SLE12 config
- Use update-alternatives mechanism for octave binary
* Tue Mar 22 2016 dmitry_r@opensuse.org
- Update to version 4.0.1
  * Bugfix release
* Tue Feb 23 2016 ro@suse.de
- vendor is ibm on s390, not suse
* Fri Oct 23 2015 dvaleev@suse.com
- Add disk constraints. Some workers might have enabled build in
  tmpfs. Where the space is limited.
* Sun Sep 13 2015 dmitry_r@opensuse.org
- Fix desktop menu category
* Thu Jul 23 2015 dmitry_r@opensuse.org
- Add build config for openSUSE:42
* Fri May 29 2015 dmitry_r@opensuse.org
- Update to version 4.0.0
  * See icluded NEWS file for details
- Drop obsolete patches:
  * octave-3.8.0-llvm-3.4.patch
  * octave-suitesparse-4.4.patch
  * octave-unzip-info-in-gui.patch
- Add RPM macros to octave-devel package
  * octave.macros
* Mon Feb 23 2015 dmitry_r@opensuse.org
- Fix unzipping compressed info files when running the gui [boo#918942]
  * octave-unzip-info-in-gui.patch
- Disable JIT compilation by default
- Set build settings for SLE11
* Wed Nov 12 2014 dmitry_r@opensuse.org
- Set build settings for SLE12
* Fri Oct 31 2014 dmitry_r@opensuse.org
- Fix build with latest SuiteSparse library
  * octave-suitesparse-4.4.patch
- Restore SuiteSparse linking hack for openSUSE <= 13.1
* Sat Oct 11 2014 dmueller@suse.com
- fix filelist on armv6/7hl: triplet is gnueabi, not gnu
* Fri Aug 22 2014 dmitry_r@opensuse.org
- Move GUI localization files to octave-gui package
* Fri Aug 15 2014 dmitry_r@opensuse.org
- Fix runtime dependencies: makeinfo instead of texinfo [bnc#892123]
* Wed Aug 13 2014 dmitry_r@opensuse.org
- Update to version 3.8.2
  * Bugfix release, see included ChangeLog file for details
- Drop suitesparse linking hack [bnc#883683]
* Thu Jun 19 2014 dmitry_r@opensuse.org
- Build with FFTW3 multi-threading support
* Tue Apr 22 2014 dmitry_r@opensuse.org
- Enable OpenMP support
* Fri Mar  7 2014 dmitry_r@opensuse.org
- Update to version 3.8.1
  * Bugfix release, see included ChangeLog file for details
  * removed obsolete octave-3.8.0-gzip-compressed-info.patch
- Disable JIT support for non-x86 architectures
* Sat Feb  1 2014 dmitry_r@opensuse.org
- Fix build with LLVM-3.4
  * octave-3.8.0-llvm-3.4.patch
* Thu Jan  2 2014 dmitry_r@opensuse.org
- Fix loading gzip-compressed info files [bnc#857130]
  * octave-3.8.0-gzip-compressed-info.patch
* Mon Dec 30 2013 dmitry_r@opensuse.org
- Add octave-gui as recommended dependence
- Build with jit support
* Sat Dec 28 2013 dmitry_r@opensuse.org
- Update to version 3.8.0
  * See included NEWS and ChangeLog files for details
- Removed obsolete octave-gcc48-mex_remove_externc.patch
* Sun Jul 28 2013 klaussfreire@gmail.com
- Added octave-gcc48-mex_remove_externc, fixes an issue when
  building packages that include mex.h in gcc 4.8
* Wed May  1 2013 dmitry_r@opensuse.org
- Cleanup recommended packages
* Sat Mar 30 2013 dmitry_r@opensuse.org
- Move documentation to octave-doc package
* Thu Mar 14 2013 pgajdos@suse.com
- minor spec file adjustment
* Fri Mar  8 2013 dmitry_r@opensuse.org
- Fix native graphics support for openSUSE 12.3 [bnc#808530]
* Thu Feb 28 2013 dmitry_r@opensuse.org
- Update to version 3.6.4
  * See included ChangeLog file for details
- Enable post build tests
- Enable paralell build
* Thu Feb  7 2013 dmitry_r@opensuse.org
- Enable native graphics
* Wed Dec 12 2012 pgajdos@suse.com
- install octave.pc file [bnc#793682]
  + source octave.pc.in
* Mon Dec  3 2012 pgajdos@suse.com
- local rc file into /etc (Dieter Jurzitza) [bnc#792507]
* Tue Oct 30 2012 dieter.jurzitza@t-online.de
- add makeinfo to BuildRequires
* Fri Oct 26 2012 badshah400@gmail.com
- Update to version 3.6.3:
  + Too many bug-fixes to list, see installed CHANGELOG file for a
    list.
- Drop octave-gets.patch, incorporated upstream.
* Tue Sep 18 2012 idonmez@suse.com
- Add BuildRequires on texinfo (instead of makeinfo) and texlive-dvips
* Tue Sep 11 2012 pgajdos@suse.com
- fix /etc/ld.so.conf.d/octave.conf [bnc#779072]
* Sat Sep  8 2012 idonmez@suse.com
- Add explicit build dependency on makeinfo
* Tue Aug 21 2012 dmitry@roshchin.org
- Change packages directories owner
* Sun Aug 19 2012 scorot@free.fr
- fix umfpack and cholmod linking according to recent suitesparse
  update
- enable arpack support
* Sun Jul 29 2012 aj@suse.de
- Fix build with missing gets declaration (glibc 2.16)
* Fri Jun  1 2012 pgajdos@suse.com
- updated to 3.6.2:
  * fix bad two-arg call of randperm
  * perform convolution properly independently of matrix orientation
  * implement proper op() indexing for diagonal matrices
  * poissrnd should return zero when lambda = 0
  * ensure isargout is not sticky
  * etc., see ChangeLog
* Fri May 11 2012 scorot@free.fr
- remove conditional BuildRequires for blas and lapack since
  recent lapack now build correctly for all suse version
- recommends blas -> blas-devel
* Mon Apr 30 2012 cfarrell@suse.com
- license update: GPL-3.0+
  See COPYING - octave is GPL-3.0+ licensed, not GPL-2.0+
* Mon Apr 16 2012 badshah400@gmail.com
- Spec file cleanup: remove Authors from description, remove
  conditionals referring to obsolete suse_versions.
* Fri Apr 13 2012 badshah400@gmail.com
- Modify BuildRequires to match recent name changes of lapack and
  blas in project.
* Tue Feb 28 2012 pgajdos@suse.com
- build against fltk (native graphics)
- build against arpack
* Mon Feb 27 2012 pgajdos@suse.com
- updated to 3.6.1:
  * removed qhull.patch
* Mon Jan 30 2012 pgajdos@suse.com
- build against 2012.1
* Mon Jan  9 2012 pgajdos@suse.com
- thanks to Martin Helm: remove octave-umfpack.patch and
  use --with-umfpack configure switch instead
* Thu Dec  1 2011 pgajdos@suse.com
- again build against hdf5
* Tue Nov 15 2011 pgajdos@suse.com
- don't build against hdf5 for now, hdf5 is not building against
  12.1 and Factory
* Mon Oct 24 2011 pgajdos@suse.com
- updated to 3.4.3:
  * removed unneeded tar-cond.patch
* Wed Oct 12 2011 pgajdos@suse.com
- build against Mesa-devel and fltk-devel conditional, use gnuplot
  rather
* Fri Oct  7 2011 pgajdos@suse.com
- fixed tar(), see
  http://trac.imagemagick.org/changeset/5359
  * tar-cond.patch
* Wed Oct  5 2011 pgajdos@suse.com
- build against Mesa-devel, fltk-devel -> native graphics
- really build against cxsparse
- build against qrupdate
* Mon Oct  3 2011 pgajdos@suse.com
- really build against umfpack
* Sat Oct  1 2011 pgajdos@suse.com
- build against suitesparse-devel instead of umfpack-devel (umfpack
  is part of suitesparse package from now on)
* Tue Sep 20 2011 pgajdos@suse.com
- build against qhull
* Tue Aug 16 2011 pgajdos@novell.com
- linked against umfpack (thanks to Christof Kauffman for
  notification)
* Tue Jul 26 2011 pgajdos@novell.com
- updated to 3.4.2
* Thu Jun 16 2011 pgajdos@novell.com
- updated to 3.4.1
  * no-return-in-nonvoid.patch
* Sun May 29 2011 werner.ho@gmx.de
- fixed hdf5-devel package name
* Tue Feb 15 2011 pgajdos@suse.cz
- updated to 3.4.0
* Thu Jan 13 2011 pgajdos@suse.cz
- downgrade back to 3.2.4 stable
* Fri Jan  7 2011 pgajdos@suse.cz
- build against GraphicsMagick
- updated to 3.3.54
* Mon Feb 15 2010 pgajdos@suse.cz
- updated to 3.2.4 (see NEWS and ChangeLog)
* Mon Nov 23 2009 pgajdos@suse.cz
- better handling of library path in the specfile [bnc#557340]
* Wed Nov 11 2009 pgajdos@suse.cz
- updated to 3.2.3 (see NEWS and ChangeLog)
- fixed [bnc#552978]
* Thu Aug  6 2009 pgajdos@suse.cz
- updated to 3.2.2
  - bugfix release
* Mon Jun 22 2009 pgajdos@suse.cz
- updated to version 3.2.0 (see NEWS)
* Tue Apr 14 2009 pgajdos@suse.cz
- updated to 3.0.5:
  * last bug-fixing-release
* Thu Mar 19 2009 pgajdos@suse.cz
- removed octave-3.0.3.patch completely [bnc#480571]
* Wed Mar 18 2009 pgajdos@suse.cz
- cstring -> string.h in patch [bnc#480571]
* Thu Feb 26 2009 pgajdos@suse.cz
- added texinfo to the Requires [bnc#285607]
* Mon Jan 26 2009 pgajdos@suse.cz
- added some packages to Recommends [bnc#468395]
* Tue Jan 13 2009 pgajdos@suse.cz
- updated to 3.0.3:
  * next bug-fixing release
* Mon Sep  8 2008 pgajdos@suse.cz
- updated to 3.0.2:
  * next bug-fixing release
* Wed Jul  2 2008 pgajdos@suse.cz
- build againist hdf5 1.8.1 -- using compatibility -DH5_USE_16_API
* Mon Jun 23 2008 pgajdos@suse.cz
- new version 3.0.1:
  * bug-fixing release
* Tue Mar 25 2008 pgajdos@suse.cz
- new version 3.0.0 moved from OBS, project science
  * improved compatibility with Matlab (tm)
  * bugfixes
- newly linked optional libraries: curl, hdf5, glpk
* Mon Nov 19 2007 pgajdos@suse.cz
- %%{_datadir}/octave/site/m/startup/octaverc linked to /etc/octave
  and marked as %%config(noreplace)
- several minor spec file cleanups
* Wed Oct 17 2007 pgajdos@suse.cz
- fixed build with new gcc -- added missing includes
  * missing-includes.patch
* Wed Jul 25 2007 pgajdos@suse.cz
- supressed paralell building which fails at least on some
  architectures
* Wed Jul 11 2007 pgajdos@suse.cz
- updated to 2.9.12 and removed randlib [#279883]
- without-randlib.patch
* Thu Jun 21 2007 pgajdos@suse.cz
- added texinfo to Requires
* Fri May 25 2007 pgajdos@suse.cz
- made subpackage octave-devel
* Sat Apr 21 2007 aj@suse.de
- Use texlive.
* Thu Jun 22 2006 ro@suse.de
- remove selfprovides
* Wed May 24 2006 anicka@suse.cz
- update to 2.1.73
  - bugfix release
* Mon Feb 13 2006 anicka@suse.cz
- require gcc-fortran (fixes #150047)
* Wed Feb  1 2006 anicka@suse.cz
- add -Os to FFLAGS (fixes #136787)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 kukuk@suse.de
- Add gmp-devel to nfb
* Thu Jan  5 2006 anicka@suse.cz
- update to 2.1.72
* Mon Nov 14 2005 anicka@suse.cz
- fix build (gcc 4.1)
* Tue Nov  1 2005 anicka@suse.cz
- fix build (move code around in CMatrix.cc)
* Tue Jun 28 2005 anicka@suse.cz
- update to 2.1.71
* Wed May 11 2005 ro@suse.de
- fix build with gcc4
* Mon Apr 18 2005 mcihar@suse.de
- GNU Fortran 77 compiler now requires gmp, let's add it
- still doesn't compile, because GCC: TODO: Functions with alternate entry points
* Tue Dec 21 2004 mcihar@suse.cz
- update to 2.1.64
- do not include info pages, as they are out of date
- string patching was not needed for long time, so drop the patch
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Wed Aug  4 2004 mcihar@suse.cz
- update to 2.1.57
* Fri Mar  5 2004 mcihar@suse.cz
- really compile with -fno-strict-aliasing
- doesn't need f2c at all
* Fri Mar  5 2004 mcihar@suse.cz
- update to 2.1.55
- fix info pages installation
- add some docs
- use -fno-strict-aliasing
* Fri Jan  9 2004 adrian@suse.de
- add %%run_ldconfig
- use RPM_OPT_FLAGS
* Fri Aug 29 2003 mcihar@suse.cz
- info pages should not be executable
* Wed Aug 13 2003 ro@suse.de
- fix info page installation again (thanks to DJurzitza)
* Wed Jul 30 2003 ro@suse.de
- install more info pages
* Thu Jun 26 2003 ro@suse.de
- remove traces of buildroot from installed files
* Wed Jun 11 2003 ltinkl@suse.cz
- updated sources to version 2.1.49
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Mar  3 2003 ro@suse.de
- added info dir entries
* Tue Feb 25 2003 mcihar@suse.cz
- removed -mminimal-toc as it is now part of RPM_OPT_FLAGS for ppc64
- added gnuplot to requires
* Mon Feb 10 2003 mcihar@suse.cz
- used %%install_info macro (fixes bug #23443)
* Wed Feb  5 2003 mcihar@suse.cz
- removed RPM_OPT_FLAGS="$RPM_OPT_FLAGS -mminimal-toc" for ppc64
  (fixes bug #23266)
- updated to 2.1.44
* Fri Nov 22 2002 mcihar@suse.cz
- updated to 2.1.40, mostly only configure and automake fixes, it
  also fixes sstream and some other smaller issues with gcc 3.3
- fixed multiline string
* Tue Aug  6 2002 mcihar@suse.cz
- updated to 2.1.36
* Sat Jun 29 2002 olh@suse.de
- build with -mminimal-toc on ppc64, use RPM_OPT_FLAGS for CFLAGS
* Tue May 21 2002 ro@suse.de
- call suse_update_config also for kpathsea subdir
* Wed May  8 2002 ro@suse.de
- fix for latest gcc-snapshot
* Fri Apr 19 2002 coolo@suse.de
- updating to octave 2.1.35 as octave 2.0.1[67] were hopeless
  with gcc 3.1 (gave up after 2 days of work)
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Fri May  5 2000 bubnikv@suse.cz
- added buildroot
- /usr/execlib/octave moved to /usr/lib/octave according to FHS 2.1
* Mon Feb 21 2000 ro@suse.de
- update to 2.0.16
* Tue Jan 25 2000 ro@suse.de
- update to 2.0.15
- man,info to /usr/share using macro
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Jul 13 1999 ro@suse.de
- update to 2.0.14
* Thu May 20 1999 ro@suse.de
- use CFLAGS="-D_GNU_SOURCE"
* Mon Nov 23 1998 ro@suse.de
- update to 2.0.13 / builds with glibc
* Tue Oct  6 1998 ro@suse.de
- BETA: added f2c to neededforbuild
* Wed Jan 28 1998 ro@suse.de
- removed libhistory.so & libreadline.so as well and link static
  to these
* Mon Nov 17 1997 bs@suse.de
- removed libhistory.a & libreadline.a from file list.
* Wed Nov 12 1997 ro@suse.de
- minor changes in specfile
  setting host to ARCH-suse-linux
* Mon Nov 10 1997 ro@suse.de
- new version 2.0.9
* Tue Oct  7 1997 ro@suse.de
- prepared spec file
- added README-GCC-2.7.? patches
